@@ -1296,6 +1296,17 @@ class DeepSR(object):
             self.modelfile=args['modelfile']
             args_has_build_function = True
 
+            #                                                 #
+            # -- Import all member methods from the module -- #
+            #                                                 #
+            funcs = [o[0] for o in getmembers(module, isfunction)]
+
+            for fn in funcs: # member methods defined in the module file
+                method = MethodType(getattr(module, fn), self)
+                setattr(self, fn, method)
+            # -- done -- #
+
+
             # take setting from settings dictionary that exist in the module
             for key in module.settings.keys():
                 setattr(self, key, module.settings[key])
